==> zio-aws-proton_2.13-7.21.15.11-sources.jar: zio/aws/proton/model/ListEnvironmentOutputsRequest.scala <==
package zio.aws.proton.model
import zio.aws.proton.model.primitives.{
  EmptyNextToken,
  ResourceName,
  DeploymentId
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListEnvironmentOutputsRequest(
    deploymentId: Optional[DeploymentId] = Optional.Absent,
    environmentName: ResourceName,
    nextToken: Optional[EmptyNextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.proton.model.ListEnvironmentOutputsRequest = {
    import ListEnvironmentOutputsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.proton.model.ListEnvironmentOutputsRequest
      .builder()
      .optionallyWith(
        deploymentId.map(value => DeploymentId.unwrap(value): java.lang.String)
      )(_.deploymentId)
      .environmentName(ResourceName.unwrap(environmentName): java.lang.String)
      .optionallyWith(
        nextToken.map(value => EmptyNextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.proton.model.ListEnvironmentOutputsRequest.ReadOnly =
    zio.aws.proton.model.ListEnvironmentOutputsRequest.wrap(buildAwsValue())
}
object ListEnvironmentOutputsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.proton.model.ListEnvironmentOutputsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.proton.model.ListEnvironmentOutputsRequest =
      zio.aws.proton.model.ListEnvironmentOutputsRequest(
        deploymentId.map(value => value),
        environmentName,
        nextToken.map(value => value)
      )
    def deploymentId: Optional[DeploymentId]
    def environmentName: ResourceName
    def nextToken: Optional[EmptyNextToken]
    def getDeploymentId: ZIO[Any, AwsError, DeploymentId] =
      AwsError.unwrapOptionField("deploymentId", deploymentId)
    def getEnvironmentName: ZIO[Any, Nothing, ResourceName] =
      ZIO.succeed(environmentName)
    def getNextToken: ZIO[Any, AwsError, EmptyNextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.proton.model.ListEnvironmentOutputsRequest
  ) extends zio.aws.proton.model.ListEnvironmentOutputsRequest.ReadOnly {
    override val deploymentId: Optional[DeploymentId] = zio.aws.core.internal
      .optionalFromNullable(impl.deploymentId())
      .map(value => zio.aws.proton.model.primitives.DeploymentId(value))
    override val environmentName: ResourceName =
      zio.aws.proton.model.primitives.ResourceName(impl.environmentName())
    override val nextToken: Optional[EmptyNextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.proton.model.primitives.EmptyNextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.proton.model.ListEnvironmentOutputsRequest
  ): zio.aws.proton.model.ListEnvironmentOutputsRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-proton_3-6.20.69.2-sources.jar: zio/aws/proton/model/ListEnvironmentOutputsRequest.scala <==
package zio.aws.proton.model
import zio.aws.proton.model.primitives.{EmptyNextToken, ResourceName}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ListEnvironmentOutputsRequest(
    environmentName: ResourceName,
    nextToken: Optional[EmptyNextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.proton.model.ListEnvironmentOutputsRequest = {
    import ListEnvironmentOutputsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.proton.model.ListEnvironmentOutputsRequest
      .builder()
      .environmentName(ResourceName.unwrap(environmentName): java.lang.String)
      .optionallyWith(
        nextToken.map(value => EmptyNextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.proton.model.ListEnvironmentOutputsRequest.ReadOnly =
    zio.aws.proton.model.ListEnvironmentOutputsRequest.wrap(buildAwsValue())
}
object ListEnvironmentOutputsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.proton.model.ListEnvironmentOutputsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.proton.model.ListEnvironmentOutputsRequest =
      zio.aws.proton.model.ListEnvironmentOutputsRequest(
        environmentName,
        nextToken.map(value => value)
      )
    def environmentName: ResourceName
    def nextToken: Optional[EmptyNextToken]
    def getEnvironmentName: ZIO[Any, Nothing, ResourceName] =
      ZIO.succeed(environmentName)
    def getNextToken: ZIO[Any, AwsError, EmptyNextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.proton.model.ListEnvironmentOutputsRequest
  ) extends zio.aws.proton.model.ListEnvironmentOutputsRequest.ReadOnly {
    override val environmentName: ResourceName =
      zio.aws.proton.model.primitives.ResourceName(impl.environmentName())
    override val nextToken: Optional[EmptyNextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.proton.model.primitives.EmptyNextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.proton.model.ListEnvironmentOutputsRequest
  ): zio.aws.proton.model.ListEnvironmentOutputsRequest.ReadOnly = new Wrapper(
    impl
  )
}
